@@ -17,7 +17,7 @@ reset() |    '-------------'   |
         |------'   |           |
         |          v           |
         |    .-------------.   |
-        |    |   Running   |   |
+        |    |   Running   |---.
         |    '-------------'   |
         |          | finish()  |
         |          |           |
@@ -129,30 +129,18 @@ CONFIG = {
         ['run', 'initialized', 'running'],
         ['finish', 'running', 'finished'],
         ['close', ['created', 'initialized', 'finished'], 'closed'],
+        {
+            'trigger': 'close',
+            'source': ['running'],
+            'dest': 'closed',
+            'before': 'on_close_while_running',
+        },
         {
             'trigger': 'reset',
             'source': ['initialized', 'finished'],
             'dest': 'initialized',
             'before': 'on_reset',
         },
-        {
-            'trigger': 'interrupt',
-            'source': ['running'],
-            'dest': None,
-            'before': 'on_interrupt',
-        },
-        {
-            'trigger': 'terminate',
-            'source': ['running'],
-            'dest': None,
-            'before': 'on_terminate',
-        },
-        {
-            'trigger': 'kill',
-            'source': ['running'],
-            'dest': None,
-            'before': 'on_kill',
-        },
     ],
     'initial': 'created',
     # 'queued': True,
