@@ -1,20 +1,28 @@
-from __future__ import annotations
-
 import asyncio
 import linecache
+import reprlib
+from contextlib import asynccontextmanager
 from logging import getLogger
-from typing import Any, AsyncIterator, Optional, Tuple
+from pathlib import Path
+from types import CodeType
+from typing import Any, AsyncIterator, Callable, Optional, Tuple, Union
 
-from apluggy import asynccontextmanager
-
-from .context import Context
 from .fsm import Machine
-from .types import PromptInfo, PromptNotice, RunInfo, StdoutInfo, TraceInfo
+from .spawned import PdbCommand
+from .types import (
+    PromptInfo,
+    PromptNo,
+    PromptNotice,
+    RunInfo,
+    StdoutInfo,
+    TraceInfo,
+    TraceNo,
+)
 from .utils import merge_aiters
 
 
 class Nextline:
-    """Nextline allows line-by-line execution of concurrent Python scripts
+    '''Nextline allows line-by-line execution of concurrent Python scripts
 
     Nextline supports concurrency with threading and asyncio. It uses multiple
     instances of Pdb, one for each thread and async task.
@@ -22,58 +30,56 @@ class Nextline:
 
     Parameters
     ----------
-    statement : str
-        A Python code as a string
+    statement : str or Path or CodeType or Callable[[], Any]
+        Typically, a Python code as a str. However, if a statement is a str
+        that is a path to an existing file, it is considered as a path to a
+        Python script. A Path object is also considered as a path to a Python
+        script. Alternatively, a statement can be a CodeType object or a
+        callable with no arguments. A statement must be picklable.
     run_no_start_from : int, optional
         The first run number. The default is 1.
     timeout_on_exit : float, optional
         The timeout in seconds to wait for the nextline to exit from the "with"
         block. The default is 3.
 
-    """
+    '''
 
     def __init__(
         self,
-        statement: str,
+        statement: Union[str, Path, CodeType, Callable[[], Any]],
         run_no_start_from: int = 1,
         timeout_on_exit: float = 3,
     ):
 
         logger = getLogger(__name__)
-        logger.debug(f"statement starts with {statement[:25]!r}")
-        logger.debug(f"The next run number will be {run_no_start_from}")
+        logger.debug(f'statement: {reprlib.repr(statement)}')
+        logger.debug(f"The run number starts from {run_no_start_from}")
 
-        self._context = Context(
+        self._machine = Machine(
             run_no_start_from=run_no_start_from,
             statement=statement,
         )
         self._timeout_on_exit = timeout_on_exit
-        self._registry = self._context.registry
+        self._registry = self._machine.registry
 
         self._started = False
         self._closed = False
 
-        # TODO: instantiate Machine here without the running asyncio loop
+    def __repr__(self):
+        # e.g., "<Nextline 'running'>"
+        return f'<{self.__class__.__name__} {self.state!r}>'
 
     async def start(self) -> None:
         if self._started:
             return
         self._started = True
-        await self._context.start()
-        self._machine = Machine(self._context)
         await self._machine.initialize()  # type: ignore
 
-    def __repr__(self):
-        # e.g., "<Nextline 'running'>"
-        return f"<{self.__class__.__name__} {self.state!r}>"
-
     async def close(self) -> None:
-        """End gracefully"""
         if self._closed:
             return
         self._closed = True
         await self._machine.close()  # type: ignore
-        await self._context.shutdown()
 
     async def __aenter__(self):
         await self.start()
@@ -84,27 +90,35 @@ class Nextline:
         await asyncio.wait_for(self.close(), timeout=self._timeout_on_exit)
 
     async def run(self) -> None:
-        """Execute the script and wait until it exits"""
+        '''Start the script execution.'''
         await self._machine.run()  # type: ignore
 
     @asynccontextmanager
-    async def run_session(self) -> AsyncIterator[Nextline]:
+    async def run_session(self) -> AsyncIterator['Nextline']:
+        '''Yield when the script execution is started and exit when it has finished.'''
         await self._machine.run()  # type: ignore
         try:
             yield self
         finally:
-            await self._machine.run_finished.wait()
+            await self._machine.wait()
 
-    def send_pdb_command(self, command: str, prompt_no: int, trace_no: int) -> None:
+    async def send_pdb_command(
+        self, command: str, prompt_no: int, trace_no: int
+    ) -> None:
         logger = getLogger(__name__)
         logger.debug(f'send_pdb_command({command!r}, {prompt_no!r}, {trace_no!r})')
-        self._machine.send_pdb_command(command, prompt_no, trace_no)
+        item = PdbCommand(
+            trace_no=TraceNo(trace_no),
+            prompt_no=PromptNo(prompt_no),
+            command=command,
+        )
+        await self._machine.send_command(item)
 
     async def interrupt(self) -> None:
-        await self._machine.interrupt()  # type: ignore
+        await self._machine.interrupt()
 
     async def terminate(self) -> None:
-        await self._machine.terminate()  # type: ignore
+        await self._machine.terminate()
 
     async def kill(self) -> None:
         await self._machine.kill()  # type: ignore
@@ -114,12 +128,12 @@ class Nextline:
         return self._machine.exception()
 
     def result(self) -> Any:
-        """Return value of the last run. always None"""
+        '''Return value of the last run. None unless the statement is a callable.'''
         return self._machine.result()
 
     async def reset(
         self,
-        statement: Optional[str] = None,
+        statement: Union[str, Path, CodeType, Callable[[], Any], None] = None,
         run_no_start_from: Optional[int] = None,
     ) -> None:
         """Prepare for the next run"""
