@@ -18,8 +18,8 @@ _T = TypeVar("_T")
 
 
 @dataclass
-class Result(Generic[_T]):
-    '''An object returned by Running after the process has exited.'''
+class ExitedProcess(Generic[_T]):
+    '''An object returned by RunningProcess after the process has exited.'''
 
     returned: _T | None
     raised: BaseException | None
@@ -28,7 +28,7 @@ class Result(Generic[_T]):
     process_exited_at: datetime
 
 
-class Running(Generic[_T]):
+class RunningProcess(Generic[_T]):
     '''An awaitable return value of `run_in_process()`.'''
 
     def __init__(
@@ -82,12 +82,12 @@ class Running(Generic[_T]):
     def kill(self) -> None:
         self.process.kill()
 
-    def __await__(self) -> Generator[None, None, Result[_T]]:
+    def __await__(self) -> Generator[None, None, ExitedProcess[_T]]:
         # "yield from" in "__await__": https://stackoverflow.com/a/48261042/7309855
         ret, exc = yield from self._task.__await__()
         process_exited_at = datetime.now(timezone.utc)
         self._log_exited(process_exited_at)
-        return Result(
+        return ExitedProcess(
             returned=ret,
             raised=exc,
             process=self.process,
@@ -101,7 +101,7 @@ ExecutorFactory: TypeAlias = 'Callable[[], ProcessPoolExecutor]'
 
 async def run_in_process(
     func: Callable[[], _T], executor_factory: ExecutorFactory | None = None
-) -> Running[_T]:
+) -> RunningProcess[_T]:
     '''Call a function in a separate process and return an awaitable.
 
     Use functools.partial to pass arguments to the function.
@@ -117,9 +117,9 @@ async def run_in_process(
     ...     running = await starting
     ...
     ...     # Wait for the process to finish.
-    ...     result = await running
+    ...     exited = await running
     ...
-    ...     return result.returned
+    ...     return exited.returned
 
     >>> asyncio.run(simple_example())
     8
@@ -156,7 +156,7 @@ async def run_in_process(
     task = asyncio.create_task(_run())
     await event.wait()
     assert process
-    ret = Running[_T](process=process, task=task)
+    ret = RunningProcess[_T](process=process, task=task)
     return ret
 
 
